==> sonse-0.2.0.tar.gz: sonse-0.2.0/setup.py <==
"""
PyPi setup script.
"""

from setuptools import find_packages, setup

from sonse import VERSION_NUMBER

# fmt: off

setup(
    # Basic information.
    name         = "sonse",
    version      = VERSION_NUMBER,
    keywords     = "notes note-taking cli",
    description  = "Stephen's Obsessive Note-Storage Engine.",
    author       = "Stephen Malone",
    author_email = "mail@sonse.org",

    # Project description.
    long_description = open("readme.md").read(),
    long_description_content_type = "text/markdown",

    # Package specifications.
    packages = find_packages(exclude=["*tests*"]),
    python_requires  = ">=3.10",
    install_requires = ["click>=8.1"],

    # Console executables.
    entry_points = {
        "console_scripts": ["sonse=sonse.__main__:group.main"],
    },

    # Project URLs.
    project_urls = {
        "Changelog":  "https://hg.sr.ht/~rattlerake/sonse/browse/changes.md?rev=tip",
        "License":    "https://hg.sr.ht/~rattlerake/sonse/browse/license.md?rev=tip",
        "Repository": "https://hg.sr.ht/~rattlerake/sonse",
        "Issues":     "https://todo.sr.ht/~rattlerake/sonse",
    },

    # Project classifiers.
    classifiers = [
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.8",
        "Topic :: Office/Business :: News/Diary",
        "Topic :: Terminals",
        "Topic :: Utilities",
    ],
)

==> sonse-0.2.1.tar.gz: sonse-0.2.1/setup.py <==
"""
PyPi setup script.
"""

from setuptools import find_packages, setup

from sonse import VERSION_NUMBER

# fmt: off

setup(
    # Basic information.
    name         = "sonse",
    version      = VERSION_NUMBER,
    keywords     = "notes note-taking cli",
    description  = "Stephen's Obsessive Note-Storage Engine.",
    author       = "Stephen Malone",
    author_email = "mail@sonse.org",

    # Project description.
    long_description = open("readme.md").read(),
    long_description_content_type = "text/markdown",

    # Package specifications.
    packages = find_packages(exclude=["*tests*"]),
    python_requires  = ">=3.10",
    install_requires = ["click>=8.1"],

    # Console executables.
    entry_points = {
        "console_scripts": ["sonse=sonse.__main__:group.main"],
    },

    # Project URLs.
    project_urls = {
        "Changelog":  "https://github.com/rattlerake/sonse/blob/master/changes.md",
        "License":    "https://github.com/rattlerake/sonse/blob/master/license.md",
        "Repository": "https://github.com/rattlerake/sonse",
        "Issues":     "https://github.com/rattlerake/sonse/issues",
    },

    # Project classifiers.
    classifiers = [
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: End Users/Desktop",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3.10",
        "Topic :: Office/Business :: News/Diary",
        "Topic :: Terminals",
        "Topic :: Utilities",
    ],
)
